#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import print_function, absolute_import
from .parser import Parser
from . import validators

__author__ = 'mosquito'
__all__ = [Parser, validators]
__version__ = "0.5.12"
